@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-core
-version: 1.4.19
-id: yesod-core-1.4.19-b6ec8d224ea1c49c36126eee73b10ab6
-key: yesod_76zPmIEOwOE5jBTSzRfVmf
+version: 1.4.20.1
+id: yesod-core-1.4.20.1-8dce2c1559c72b98aae15f98b85f32e0
+key: yesod_G6CMFP5qGZ421DevHfB4zo
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -30,10 +30,10 @@ hidden-modules: Yesod.Core.Internal.Session
                 Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                 Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.19
-library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.19
-data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-core-1.4.19
-hs-libraries: HSyesod-core-1.4.19-76zPmIEOwOE5jBTSzRfVmf
+import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.20.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.20.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-core-1.4.20.1
+hs-libraries: HSyesod-core-1.4.20.1-G6CMFP5qGZ421DevHfB4zo
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
@@ -45,20 +45,20 @@ depends:
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
     cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
-    clientsession-0.9.1.1-763bfd866302839ae7dcaa53517a3160
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
+    clientsession-0.9.1.1-b8e6f456b3509830746dc1bc910c0131
+    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
+    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     cookie-0.4.1.6-97fa5cf54d4ed1e2644dbcebe7255b51
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
-    fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
+    fast-logger-2.4.3-07980efcfdf2821a6e4b588f1620bda1
     http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
-    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
-    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-0974645d267a817a7b3484945a31ce66
+    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
+    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
+    monad-logger-0.3.18-d371de410ef611b2a9194c84cfcdfbf6
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
@@ -66,7 +66,7 @@ depends:
     path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
     primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
@@ -78,10 +78,10 @@ depends:
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
-    wai-extra-3.0.15-954ac840c460f6e3c2fb191ca01c5fce
-    wai-logger-2.2.4.1-9478a6051df96b8d5b3214f7fcca2185
-    warp-3.2.3-6de819de378ae4c57281b63b66004254
+    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
+    wai-extra-3.0.15-e42802427c6ef24de665b6ca33fb34be
+    wai-logger-2.2.4.1-b4d6891e20083c91ee31e279044b2010
+    warp-3.2.6-828a707afef115eb99ae18cc2d425cf2
     word8-0.1.2-9a296ac80618be494d93f29b398e749d
 haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
 haddock-html: /usr/share/doc/haskell-yesod-core/html
